spannertools.fracture_all_spanners_attached_to_component
========================================================

.. autofunction:: abjad.tools.spannertools.fracture_all_spanners_attached_to_component.fracture_all_spanners_attached_to_component
